/*
 * Copyright 2012-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.autoconfigure.flyway;

import org.flywaydb.core.api.configuration.FluentConfiguration;

/**
 * Callback interface that can be implemented by beans wishing to customize the flyway
 * configuration.
 *
 * @author Stephane Nicoll
 * @since 2.1.0
 */
@FunctionalInterface
public interface FlywayConfigurationCustomizer {

	/**
	 * Customize the flyway configuration.
	 * @param configuration the {@link FluentConfiguration} to customize
	 */
	void customize(FluentConfiguration configuration);

}
